Aprs.Types.Position
(aprs v1.0.1)
Represents position data with latitude, longitude, and associated metadata.
Summary
Functions
Parse APRS lat/lon strings (e.g., "3339.13N", "11759.13W") into a map with latitude and longitude.
Return a map with latitude and longitude from decimal values.
Types
Functions
Parse APRS lat/lon strings (e.g., "3339.13N", "11759.13W") into a map with latitude and longitude.
Return a map with latitude and longitude from decimal values.