Aprs.Weather
(aprs v1.0.1)
APRS weather report parsing.
Summary
Functions
Parse an APRS weather report string. Returns a struct or error.
Parse weather data from a comment field that contains weather information. This handles cases where weather data is embedded in the comment field.
Parses a weather data string into a map of weather values.
Check if a comment contains weather data patterns using binary pattern matching.
Functions
Parse an APRS weather report string. Returns a struct or error.
Parse weather data from a comment field that contains weather information. This handles cases where weather data is embedded in the comment field.
Parses a weather data string into a map of weather values.
Check if a comment contains weather data patterns using binary pattern matching.